@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Access to the track.getInfo slice of the LastFM API
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0200';
 
 use Moo;
 use strictures 2;
@@ -69,29 +69,34 @@ sub fetch {
 
     my $tx = $self->ua->get($url);
 
-    my $data = _handle_response($tx);
+    my $data = $self->_handle_response($tx);
 
     return $data;
 }
 
 sub _handle_response {
-    my ($tx) = @_;
+    my ($self, $tx) = @_;
 
     my $data;
 
     my $res = $tx->result;
 
-    if ( $res->is_success ) {
-        my $body = $res->body;
-        try {
-            $data = decode_json($body);
+    if ($self->format eq 'json') {
+        if ( $res->is_success ) {
+            my $body = $res->body;
+            try {
+                $data = decode_json($body);
+            }
+            catch {
+                croak $body, "\n";
+            };
+        }
+        else {
+            croak 'Connection error: ', $res->message;
         }
-        catch {
-            croak $body, "\n";
-        };
     }
     else {
-        croak "Connection error: ", $res->message;
+        $data = $res->body;
     }
 
     return $data;
@@ -111,7 +116,7 @@ WebService::LastFM::TrackInfo - Access to the track.getInfo slice of the LastFM
 
 =head1 VERSION
 
-version 0.0101
+version 0.0200
 
 =head1 SYNOPSIS
 
